"""
 File       : PianaGlobals.py
 Author     : R. Aragues & D. Jaeggi
 Creation   : 2003
 Contents   : class that controls piana vocabularies, default values and database names for tables and columns
 Called from: all across piana modules

=======================================================================================================
File that sets piana vocabularies, default values and database names for tables and columns
"""

# PianaGlobals.py: class that controls piana vocabularies, default values and database names for tables and columns
#
# Copyright (C) 2005  Ramon Aragues
# author email: ramon.aragues@upf.edu and boliva@imim.es
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#    http://www.gnu.org/copyleft/gpl.html
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# University Pompeu Fabra, hereby disclaims all copyright
# interest in the program 'PIANA'
# (software for working with protein-protein interaction networks) written 
# by Ramon Aragues


# import functions needed to obtain SQL statements
#  --> calls to classes that generate sql statements are done through PianaGlobals
#      This is done this way just to centralize all interactions with piana databases
#      in this file
from PianaInsertSQL import *
from PianaSelectSQL import *





# ==========================================================
#                   PIANA DATABASE DESCRIPTION
# ==========================================================
# This will be used to retrieve values from the database.
# The variable names will remain unchanged if the database changes.
# In case the column names change, then the only thing to modify in
# the program will be the strings of this list.
# -----------------------------------------------------------------


# ================
# DATABASE TABLES
# ================

# sequence table
sequence_table = "sequence"

# protein tables
protein_table = "protein"
proteinConflicts_table = "proteinConflicts"
proteinCorrespondence_table = "proteinCorrespondence"
proteinSimilarity_table = "proteinSimilarity"
proteinPianaCounter_table = "proteinPianaCounter"
proteinSourceDB_table = "proteinSourceDB"
validProteinIds_table = "valid_protein_ids" # __mirar__ esta tabla deberia llamarse validProteinIds para ser coherente con los otros nombres
externalDatabase_table = "externalDatabase"
externalDatabaseType_table = "externalDatabaseType"

# TEMPORAL
temporalData_table = "temporalData"
temp_externalID_col = "temp_externalID"

# BLAST
blastResults_table = "blastResults"



# external protein identifiers tables

# External protein identifiers tables are stored in the database

uniprotEntry_table = "uniprotEntry"
uniprotAcc_table = "uniprotAcc"
geneName_table = "geneName"
pdb_table = "pdb"
gi_table = "gi"
geneID_table = "geneID"
unigene_table = "unigene"
refseq_table = "refseq"
ensembl_table = "ensembl"
accessionNumber_table = "accessionNumber"
proteinExternalId_table = "proteinExternalId"
externalDatabaseType_table = "externalDatabaseType"



# protein attributes relationship tables
proteinReactome_table = "proteinReactome"
proteinEC_table = "proteinEC"
proteinCog_table = "proteinCog"
proteinGo_table = "proteinGo"
interPro_table = "interPro"
pfam_table = "pfam"
proteinScop_table = "proteinScop"
proteinCath_table = "proteinCath"
proteinProsite_table = "proteinProsite"
#proteinSpecies_table = "proteinSpecies"
proteinDescription_table = "proteinDescription"
proteinKeyword_table = "proteinKeyword"
proteinFunction_table = "proteinFunction"
proteinSubcellularLocation_table = "proteinSubcellularLocation"
proteinDisease_table = "proteinDisease"
proteinDBAliCluster_table = "proteinDBAliCluster"
proteinMIM_table = "proteinMIM"

# protein attributes tables
reactome_table = "reactome"
species_table = "species"
ec_table = "ec"
cog_table = "cog"
go_table="go"
go_term2term_distance_table="go_term2term_distance"
mim_table="mim"


# interaction tables
interaction_table = "interaction"
interactionMethod_table = "interactionMethod"
#interactionSourceDB_table = "interactionSourceDB" # does not exist anymore
interactionFeatures_table = "interactionFeatures"
interactionScores_table = "interactionScores"
interactionProteinSource_table = "interactionProteinSource"


# ================
# DATABASE COLUMNS
# ================
#
# This is the place where the column names in piana databases are centralized
#
# Therefore, if there are any column name changes, or columns added to a piana database, it must be reflected here 
#

# ---------------------------
# Protein Descriptors columns
# ---------------------------

# Columns of table protein_table

proteinPiana_col = "proteinPiana"
taxID_col = "taxID"
              # - sequenceID_col same as in sequence table
              #- sourceDBID field same as in protein_table

# Columns of table sequence_table

sequenceID_col = "sequenceID"
sequence_col ="sequence"
sequenceMD5_col ="sequenceMD5"
sequenceLength_col ="sequenceLength"
sequenceMW_col ="sequenceMW"
sequenceIP_col ="sequenceIP"
              #- taxID field same as in species_table

# Columns of table proteinExternalId
proteinExternalId_col = "proteinExternalId"
externalIdType_col = "externalIdType"
                  #- proteinPiana field same as in protein_table
                  #- sourceDBID field same as in protein_table



# Columns of table proteinConflicts_table
conflictID_col ="conflictID"
description_col ="description"
                    #- proteinPiana field same as in protein_table

# Columns of table proteinCorrespondence_table
                    #- proteinPiana field same as in protein_table
                    #- proteinMD5 field same as in protein_table
                    #- taxID field same as in species_table
                    
# Columns of table proteinSimilarity_table
                    #- proteinPianaA_col field same as in interaction_table
                    #- proteinPianaB_col field same as in interaction_table
                    
# Columns of table proteinPianaCounter_table
proteinPianaCounter_col ="proteinPianaCounter"
sequenceIDCounter_col = "sequenceIDCounter"
interactionCounter_col = "interactionCounter"

# Columns that should be maintained with the same name in all tables:
sourceDBID_col = "sourceDBID"
                    #- proteinPiana field same as in protein_table


# ------------------------------------
# Protein External identifiers columns
# ------------------------------------
sourceDBID_col = "sourceDBID"

# Columns of table uniprotEntry_table
uniprotEntry_col ="uniprotEntry"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table uniprotAcc_table
uniprotAcc_col ="uniprotAcc"
isPrimary_col ="isPrimary"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table geneName_table
geneName_col ="geneName"
                    #- isPrimary_col field same as everywhere
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table


# Columns of table gi_table
giID_col ="giID"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table accessionNumber_table
accessionNumber_col ="accessionNumber"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table _table
geneID_col ="geneID"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table _table
unigene_col ="unigene"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table _table
refseq_col ="refseq"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

# Columns of table _table
ensembl_col ="ensembl"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

                    
# Columns of table pdb_table
pdbID_col ="pdbID"
chain_col = "chain"
pdb_chain_col = "pdb_chain"
range_col = "range"
                    #- sourceDBID_col field same as everywhere
                    #- proteinPiana field same as in protein_table

                    
# Columns of table protein_id_intDB_table
#     intdbID is composed of a string idenfying the code
#     and the code itself (eg. dip_uid:203N)
#      ->valid strings for identying codes are:
#            - dip_uid
#            - hprd_id
#
intdbID_col ="intdbID"
                    #- proteinPiana field same as in protein_table
                    #- sourceDBID_col field same as everywhere

# ---------------------------------------
# External Ids and database  columns
# ---------------------------------------

databaseName_col = "databaseName"
databaseVersion_col = "databaseVersion"
databaseFile_col = "parsed_file"
databaseDate_col = "date"
databaseDescription_col = "databaseDescription"
databaseInteger_col = "databaseInteger"

# table valid_protein_ids columns
proteinTypeId_col = "proteinTypeId"
proteinTable_col = "proteinTable"
externalIdColumn_col = "externalIdColumn"
externalIdDescription_col = "externalIdDescription"

databaseType_col = "databaseType"



# ---------------------------------------
# Protein attributes relationship columns
# ---------------------------------------

# Columns of table proteinReactome
proteinReactomeSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        #- reactomeID same as in reactome_table

# Columns of table proteinEC_table
proteinECSource_col = sourceDBID_col
        #- ecID field same as in ec_table
        #- proteinPiana field same as in protein_table

# Columns of table proteinCog_table
proteinCogSource_col = sourceDBID_col
        #- cogID field same as in cog_table
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinGo_table
proteinGoSource_col = sourceDBID_col

# Columns of table interPro_table
interProID_col ="interProID"
interProDescription_col = "interProDescription"
interProSource_col = sourceDBID_col
                    #- proteinPiana field same as in protein_table

# Columns of table pfam_table
pfamID_col ="pfamID"
pfamDescription_col = "pfamDescription"
pfamSource_col = sourceDBID_col
                    #- proteinPiana field same as in protein_table

# Columns of table prosite_table
prositeID_col ="prositeID"
prositeSource_col = sourceDBID_col
                    #- proteinPiana field same as in protein_table

                    
# Columns of table proteinScop_table
proteinScopSource_col = sourceDBID_col
cf_col = "cf"
sf_col = "sf"
fa_col = "fa"
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinCath_table
proteinCathSource_col = sourceDBID_col
c_col = "c"
a_col = "a"
t_col = "t"
h_col = "h"
cathID_col = "cathID"
segmentID_col = "segmentID"
res_start_col = "res_start"
res_end_col = "res_end"
        #- proteinPiana field same as in protein_table

# Columns of table proteinSpecies_table
#proteinSpeciesSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        #- taxID field same as in species_table


# Columns of table proteinDescription_table
proteinDescription_col = "proteinDescription"
proteinDescriptionSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinKeyword_table
proteinKeyword_col = "proteinKeyword"
proteinKeywordSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinFunction_table
proteinFunction_col = "proteinFunction"
proteinFunctionSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinSubcellularLocation_table
proteinSubcellularLocation_col = "proteinSubcellularLocation"
proteinSubcellularLocationSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table

# Columns of table proteinDisease_table
proteinDisease_col = "proteinDisease"
proteinDiseaseSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table

# Columns of table proteinMIM_table
proteinMIM_col = "mimID"
proteinMIMSource_col = sourceDBID_col
        #- proteinPiana field same as in protein_table
        
# Columns of table proteinDBAliCluster_table

DBAliclusterID_col = "DBAliclusterID"
DBAliclusteringMethod_col = "DBAliclusteringMethod"
patchResidues_col = "patchResidues"
        #- proteinPiana field same as in protein_table
        #- sourceDBID_col field same as everywhere

# ---------------------------------------
# Protein attributes columns
# ---------------------------------------

# Columns of table reactome_table
reactomeID_col = "reactomeID"
reactomeDescription_col = "pathwayDescription"
reactomeSource_col = sourceDBID_col

# Columns of table species_table
taxID_col = "taxID"
speciesName_col = "speciesName"
speciesDescription_col = "speciesDescription"
speciesKingdom_col = "speciesKingdom"
speciesSource_col = sourceDBID_col

# Columns of table ec_table
ecID_col ="ecID"
ecDescription_col = "ecDescription"
ecSource_col = sourceDBID_col

# Columns of table cog_table
cogID_col ="cogID"
cogDescription_col = "cogDescription"
cogFunction_col = "cogFunction"
cogSource_col = sourceDBID_col

# Columns of table go_table
goID_col ="goID"
go_name_col = "name"
go_acc_col = "acc"
go_term_type_col = "term_type"
go_distance2root = "distance2root"
goSource_col = sourceDBID_col

# Columns of table go_term2term_distance_table
go_term2term_distance_term1_col="go_term1"
go_term2term_distance_term2_col="go_term2"
go_term2term_distance_col="distance"

# Columns of table mim_table
mimID_col="mimID"
mim_title_col="mimTitle"
mim_keywords_col="mimKeywords"
mimSource_col = sourceDBID_col


# --------------------------------------
# external protein databases Columns   
# --------------------------------------

# Columns of table uniprotInfo_table
uniprotEntry_col= "uniprotEntry" 
data_class_col= "data_class"
description_col= "description"
organism_col= "organism" 
organelle_col= "organelle"
        #- proteinPiana field same as in protein_table
        #- proteinMW field same as in protein_table
        #- proteinSequenceLength field same as in protein_table

# ---------------------
# Blast columns
# ---------------------
sequenceID_A_col = "sequenceID_A"
sequenceID_B_col = "sequenceID_B"
score_col = "score"
bit_score_col = "bit_score"
start_A_col = "start_A"
end_A_col = "end_A"
start_B_col = "start_B"
end_B_col = "end_B"
identities_col = "identities"
similarity_col = "similarity"
gaps_col = "gaps"
program_col = "program"
filter_col = "filter"
        
# --------------------
# Interaction Columns
# --------------------


# Columns of table interaction_table

interactionPiana_col ="interactionPiana"
proteinPianaA_col ="proteinPianaA"
isSourceA_col ="isSourceA"
proteinPianaB_col ="proteinPianaB "
isSourceB_col ="isSourceB "
interactionConfidence_col ="interactionConfidence"
                    #- sourceDBID_col field same as everywhere

# commented because it doesn't exist anymore
# Columns of table interactionSourceDB_table
#confidenceAssigned_col ="confidenceAssigned"
                    #- sourceDBID field same as in interactionSourceDB_table
                    #- interactionPiana field same as in interaction_table


# Columns of table interactionMethod_table
methodID_col ="methodID"
                    #- interactionPiana field same as in interaction_table
                    #- sourceDBID_col field same as everywhere
                    
# Columns of table interactionFeatures_table
pubmedID_col ="pubmedID"
                    #- interactionPiana field same as in interaction_table
                    #- sourceDBID_col field same as everywhere


# Columns of table interactionScores_table
equiv_nscore_col = "equiv_nscore"
equiv_nscore_transferred_col = "equiv_nscore_transferred"
equiv_fscore_col = "equiv_fscore"
equiv_pscore_col = "equiv_pscore"
equiv_hscore_col = "equiv_hscore"
array_score_col = "array_score"
array_score_transferred_col = "array_score_transferred"
experimental_score_col = "experimental_score"
experimental_score_transferred_col = "experimental_score_transferred"
database_score_col = "database_score"
database_score_transferred_col = "database_score_transferred"
textmining_score_col = "textmining_score"
textmining_score_transferred_col = "textmining_score_transferred"
combined_score_col = "combined_score"
                    #- interactionPiana field same as in interaction_table
                    #- sourceDBID_col field same as everywhere


# Columns of table interactionProteinSource_table
        #- interactionPiana field same as in interaction_table
        #- proteinPiana field same as in protein_table
        #- sourceDBID_col field same as everywhere


#Columns of table go_parent_relationship

go_parent_col = "go_parent"
go_son_col = "go_son"
 



# ==========================================================
# DEFAULTS VALUES USED IN PIANA
# ==========================================================


# ----------------------------------------------------------
# Constants for GO hierarchy values
# ----------------------------------------------------------
huge_distance = 1000
huge_depth = 1000

# ----------------------------------------------------------
# Clustering defaults
# ----------------------------------------------------------
huge_value = 100

# ==========================================================
# DICTIONARIES OF EXTERNAL KEYWORDS
# ==========================================================
#
# The following dictionaries link external keywords referring
# to a given entity to the keyword that Piana will use internally
# to refer that entity
#
# The keys of the dictionaries are the piana identifiers, and the
# list contents those values that can be used by the user
# 
# Attention! All strings must be in lowercase!! (because of the way of checking for similar strings)
# Attention! Remember that strings cannot be longer than 20 chars!!!  (database limitations)
# ---------------------------------------------------------------


# --------
# Definition of methods used to find interactions
#   -- any new insertion of an interaction must make sure that the method name
#      appears here and is normalized
#
#   -- method_names follows the structure of a dictionary, with keys being the normalized name and content the different
#      names found in databases to refer to that name (e.g. method affinity is called in DIP "Affinity chromatogra").
#
#   --  method normalized names should not be longer than 20 characters
#       (if you need to do so, you can change field methodID_col in piana database table interactionMethod_table)
#
# --------
# Attention! Use lowercase for keys and values, even if the external database uses upper case
#            for the method description
#
# Attention! Remember than the method name (ie. the dictionary key) cannot be longer than 20 chars!!! 

# ATTENTION!!! Do not change the description of methods! Otherwise, we won't be able to transform to standard form
#              the methods as described in external databases
#              (e.g. MIPS describes method as "coip: coimmunoprecipitation")
#              If you have a new description for the method, just add a new element to the list



## methods_tree = { "proteincomplassay": ["cytcomplassay","membrcomplassay","transcrcomplassay","compl"], #protein complementation assay
##                  "cytcomplassay": ["dhfr","ubiquitin","betagalactcompl","adenylate","gfpcompl","betalactcompl"], #cytoplasm complementation assay
##                  "membrcomplassay": ["mappit","toxcat"], #membrane complementation assay
##                  "transcrcomplassay": ["gallex","y2hassay","3hybrid","transcrcompl","lambda"], #transcriptional complementation assay

##                  "y2hassay":["y2h","y2hpool","y2array"], # yeast two hybrid assay
                 

##                  "phagedisplay": ["t7phage","lambdaphage","phage"],

##                  "enzimatic":["polimassay","phosphassay","kinassay","methiltransassay","deacetilassay","enzimaticassay","gtpaseassay"],

##                  "footprinting": ["footprint"],

##                  "copurification":[],

##                  "array":["arraytec","antibodyarray","microarray"],

##                  "unclass":["unclassified"],

##                  "colocalization":["coloc","elecmicr","flumicro","electom","immstain","immloc"]

                 

                 
##                  }

method_names = { # COMPLEMENTATION ASSAY
                 "dhfr":["dhfr", "dhfr reconstruction"],
                 "ubiquitin":["ubiquitin", "split-ubiquitin syst", "split-ubiquitin system", "ubiquitin reconstruction", "ub reconstruction"],  #NO ESTOY SEGURO DE QUE TODOS LO SEAN 
                 "betagalactcompl": ["betagalactcompl","galactosidase", "beta galactosidase", "beta galactosidase complementation"],
                 "adenylate":["adenylate", "adenylate cyclase"],
                 "gfpcompl":["gfpcompl","gfp complementation","bimolecular fluorescence complementation"],  # HE ANADIDO "flubi" y "flubi", "bimolecular fluorescence complementation"
                 "betalactcompl": ["betalactcompl","beta lactamase complementation"],
                 "mappit":["mappit"],
                 "toxcat":["toxcat"],
                 "gallex":["gallex"],
                 "transcrcompl":["transcrcompl","transcription compl","transcriptional complementation","transcript","transcription assay"], #HE ANADIDO "transcript" Y "transcription assay"
                 "compl":["compl","complementation","protein complementation assay"],
                 "lambda":["lambda","lambda fusion"],

                 #TWO HYBRID
                 #"y2h":["y2h","y2h","two hybrid test","yeast2hybrids", "yeast two hybrids", "two hybrid", "2h","two-hybrid","yeast-two hybrid"],
                 #"y2hpool": ["y2hpool","2h fragment pooling","two hybrid pooling", "two hybrid pooling approach","two hybrid fragment pooling approach"],
                 #"y2harray": ["y2harray","two hybrid array"],
                 #"3hybrid": ["3hybrid", "3 hybrid method","protein tri hybrid"],
                 #Unifyed:
                 "y2h":["y2h","y2h","two hybrid test","yeast2hybrids", "yeast two hybrids", "two hybrid", "2h","two-hybrid","yeast-two hybrid",
                        "y2hpool","2h fragment pooling","two hybrid pooling", "two hybrid pooling approach","two hybrid fragment pooling approach",
                        "y2harray","two hybrid array",
                        "3hybrid", "3 hybrid method","protein tri hybrid"],
                 

                 # DISPLAY
                    # PHAGE DISPLAY
                 #"t7phage":["t7phage","t7 phage", "t7 phage display"],
                 #"lambdaphage":["lambdaphage","lambda phage", "lambda phage display"],
                 #"phage":["phage", "phage display"],
                 # Fusion:
                 "phage":["t7phage","t7 phage", "t7 phage display",
                          "lambdaphage","lambda phage", "lambda phage display",
                          "phage", "phage display"],

                 #YEAST
                 #"yeastdisplay":["yeastdisplay","yeast display"],  puesto como facs


                 #BIOCHEMICAL
                 "otherbiochem":["biochemical activity","otherbiochem", "other biochemical", "biochemical", "other biochemical technologies"],
                 
                     # enzimatic STUDY
                 #"polimassay":["polimassay"],
                 #"protassay":["protassay","protease accessibility laddering"],
                 #"phosphassay":["phosphassay","phosphatase", "phosphatase assay"],
                 #"kinasassay":["kinassay","in gel kinase assay","vivokinas", "in vivo kinase activ", "in vivo", "in vivo kinase activity", "In vivo kinase activity assay", "protein kinase assay","htrf","kinase htrf",""],   # HE ANADIDO VIVOKINAS  # HE ANADIDO htrf...
                 #"methiltransassay":["methiltransassay","methyltransferase as","methyltran","methyltransferase radiometric assay","methyltran", "methyltransferase radiometric assay", "methyltransferase assay","radiolabeled methyl"],
                 #"deacetilassay":["deacetilassay","deacetylase assay",],
                 #"gtpaseassay": ["gtpaseassay","gtpase assay"],
                 #"enzimaticassay":["enzimaticassay","enzym", "enzymatic study","enzymatic studies","protease assay"],
                 # Fusion:
                 "enzimaticassay":["polimassay",
                                   "protassay","protease accessibility laddering",
                                   "phosphassay","phosphatase", "phosphatase assay",
                                   "kinassay","in gel kinase assay","vivokinas", "in vivo kinase activ", "in vivo", "in vivo kinase activity", "In vivo kinase activity assay", "protein kinase assay","htrf","kinase htrf",
                                   "methiltransassay","methyltransferase as","methyltran","methyltransferase radiometric assay","methyltran", "methyltransferase radiometric assay", "methyltransferase assay","radiolabeled methyl",
                                   "deacetilassay","deacetylase assay",
                                   "gtpaseassay","gtpase assay",
                                   "enzimaticassay","enzym", "enzymatic study","enzymatic studies","protease assay"],
                                   
                                   
                 

                 # FLUORESCENCE TECHNOLOGIES
                 "fluotec":["fluotec", "fluorescence technology","fluorescence","fluorescence technologies"],
                 "fluanis":["fluanis", "fluorescence anisotropy"],
                 "fludepol":["fludepol", "fluorescence depolar", "fluorescence depolarization"],
                 "fluocell":["fluocell", "fluorescence-activated cell sorting","facs","yeast display"],   #yeast display deberia ir aqui?
                 "fluores":["fluores", "fluorescent resonance energy transfer"],
                 "immflu":["immflu", "immunofluorescence"],
                 

                 # FOOTPRINTING
                 "footprint":["footprinting"],


                 # AFFINITY TECHNOLOGY
                      # COMPETITION
                 "competition":["competition", "competition binding"],
                      # Saturation
                 "saturation":["saturation","saturation binding"],
                      # Shift assay
                 "electromob":["electromob", "emsa:electrophoretic mobility", "electrophoretic mobility shift assay","emsa","emsa supershift","emsa:electrophoretic mobility shift assay",
                               "gelretard", "gel retardation assa", "gel retardation assays"],  # fused from gelretard
                      # Chromatin immunoprecipitation assays
                 "chip":["chip", "ch-ip"],

                      # Copurification
                 #"immprec":["immprec", "immunoprecipitation", "immuno", "coip: coimmunoprecipitation", "flagcoip", "flagcoip","flag co-immunoprecipitation","co-immunoprecipitation", "anti bait coimmunoprecipitation", "anti tag coimmunoprecipitation", "coimmunoprecipitation","anti bait coip","anti tag coip","coip"], # fused into affinchrom
                 "molsiev":["molsiev", "molecular sieving"],
                 "cosediment":["cosediment", "cosedimentation", "cosedimentation in solution","solution sedimentati", "cosedimentation through density gradients"],
                 "copurif":["copurif", "copurification","Co-purification"],

                 
                 #"pulldown":["pulldown", "pull down", "gst pull down", "his pull down"],  # fused into affinchrom
                 #"tandaffin":["tandaffin", "tandem affinity puri", "tandem affinity purification", "tandem affinity purification (tap)", "tapcoip", "tap", "tap tag coimmunoprecipitation"],  # fused into affinchrom

                      # Cromatography
                 "affinchrom":["affinchrom" ,"affinity chromatogra", "affinity chromatography technology", "affinity chromatography","affinity chromatography technologies", "affinity technology","affinity chrom","affinity techniques","affinity technologies", "chromatography","chromatography technologies", "reverse phase chrom","affinity capture-luminescence","affinity capture-rna","affinity capture-western",
                              "pulldown", "pull down", "gst pull down", "his pull down",
                              "tandaffin", "tandem affinity puri", "tandem affinity purification", "tandem affinity purification (tap)", "tapcoip", "tap", "tap tag coimmunoprecipitation",
                               "immprec", "immunoprecipitation", "immuno", "coip: coimmunoprecipitation", "flagcoip", "flagcoip","flag co-immunoprecipitation","co-immunoprecipitation", "anti bait coimmunoprecipitation", "anti tag coimmunoprecipitation", "coimmunoprecipitation","anti bait coip","anti tag coip","coip"],
                 "ion":["ion", "ion-exchange chromat", "ion-exchange chromatography", "ion exchange chromatography","ion exchange chrom"],

                 "overlay":["overlay", "filter overlay assay","filter binding"], # HE QUITADO filter binding de affinchrom y lo he puesto aqui

                      # Colocalization
                 "immstain":["immstain", "immunostaining", "colocalization by immunostaining"], 
                 "immloc":["immloc", "immunolocalization"],

                      # Antibody detection
                 "elisa":["elisa", "elisa: enzyme-linked immunosorbent assay", "enzyme linked immunosorbent assay"],
                 
                 # FLUORESCENCE TECHNOLOGY
                 "fluspec":["fluspec", "fluorescence spectro", "fluorescence spectroscopy", "fluorescence polarization spectroscopy", "classical fluorescence spectroscopy","fluorescence spectr","fps","fcs"],


                 # COLOCALIZATION
                 "coloc":["coloc","colocalization", "colocalization/visualisation technologies","coloc fluoresc probe","Co-localization", "colocalization by fluorescent probes", "colocalization by fluorescent probes cloning","bret"], # HE ANADIDO "bret", 
 

                 # WESTERN BLOT (AND ELECTROPHORESIS) SHOULD IT BE IN THE SAME?
                 "farwestern":["farwestern", "far-western blot", "far western blotting", "far western", "far-western" ],
                 "immblot":["immblot", "immunoblotting"],
                 "natgel":["natgel", "native gel", "native gel electroph", "native gel electrophoresis"],                 
                 "denatur":["denatur", "denaturing gel elect", "denaturing gel electrophoresis"],
                 "comigration":["comigration", "comigration in sds page","comig non denat gel", "comigration in non denaturing gel electrophoresis"],
                 "gelfilt":["gelfilt", "gel filtration chrom", "gel filtration chromatography"], 
                 #"gelretard":["gelretard", "gel retardation assa", "gel retardation assays"],   # FUSED INTO electromob
              
                 # ARRAY TECHNOLOGY
                 #"arraytec":["arraytec", "peptide array","protein array","Epistatic MiniArray Profile", "array technologies"],
                 "antibodyarray":["antibodyarray", "antibody array"],
                 #"microarray":["microarray"],
                 # Unified:
                 "arraytec":["arraytec", "peptide array","protein array","Epistatic MiniArray Profile", "array technologies",
                             "microarray"],
                 

                 # IMAGING TECHNIQUES
                 "elecmicr": ["elecmicr","electron", "electron microscopy", "transmission electron microscopy"],
                 "electom":["electom", "electron tomography","sem"],
                 "flumicro":["flumicro", "fluorescent microscopy", "fluorescence microscopy","confocal microscopy","fluorescence imaging","imaging techniques"],  # HE ANADIDO confocal microscopy...

                 

                 # GENETIC/PHENOTIPIC METHODS
                 "genetic":["genetic", "genetic interference"],
                 "phenotipic":["phenotipic","phenotypic enhancement","phenotypic suppression","synthetic growth defect","synthetic lethality","synthetic rescue"],
                 "dosage":["dosage", "dosage growth defect","dosage lethality","dosage rescue"],
                 "proteome":["proteome"],
                 "transcoexp":["transcoexp", "transient coexpressi", "transient coexpression"],
                 

                 # BIOPHISICAL TECHNIQUES
                 "circudich":["circudich", "circular dichroism","cd"],
                 "isothermal":["isothermal", "isothermal titration", "isothermal titration calorimetry","itc"],
                 "plasmon":["plasmon", "surface plasmon reso", "surface plasmon resonance","spr"],
                 "massspec":["massspec", "mass spectrometry", "mass spectrometrics", "mass spectrometric s", "mass spectrometric screening", "mass spectrometry studies of complexes","ms of complexes","Affinity Capture-MS"],  # NO TENGO CLARO EL ULTIMO...
                 "light":["light", "light scattering", "dynamic light scattering", "static light scattering","dls"],
                 "scintillation":["scintillation","spa"],
                 "nmr":["nmr", "nuclear magnetic resonance"],
                 "electronres":["electronres", "electron resonance", "resonance energy transfer","electparam", "electron paramagnetic resonance"], # LOS DOS ULTIMOS SON UN TIPO ESPECIFICO
                 
                 "photon":["photon", "photon correlation s", "photon correlation spectroscopy"],
                 "otherbiophy":["otherbiophy", "other biophysical", "biophysical"],
                 "neutron":["neutron", "neutron scattering"],
                 "atomic":["atomic", "atomic force microsc", "atomic force microscopy"],

                 # PREDICTION METHODS
                 "interologcog":["interologcog", "expcog1", "interologs by cog"],  
                 "interologscop":["interologscop", "expscop1", "interologs by scop"],
                 "scop_fa_pred":["scop_fa_pred", "predicted because their scop families have been found to interact"],
                 "pred_struct":["pred_struct","predicted from structural similarity"],
                 "prediction":["prediction","interaction prediction"],
                 "dist_patt": ["dist_patt"],

                 # String predictions
                 "neighbohood":["neighborhood", "equiv_nscore"],
                 "fusion":["fusion", "equiv_fscore"],
                 "ocurrence":["ocurrence", "equiv_pscore"],
                 "coexpress":["coexpress","coexpression", "array_score"],
                 "textmining":["textmining"],
                 "databases":["databases"],
                 "interologn":["interologn","interolog neighbours"],
                 "interologtm":["interologtm","interolog textmining"],
                 "interologcoexp":["interologcoexp"],
                 "interologdb":["interologdb","interolog database"],
                 "interologexp":["interologexp","interolog experimental"],
                 "combinedsc":["combinedsc","combined score"],
                 

                 # UNKNOWN, UNSPECIFIED
                 "unclassified":["unclassified"],


                 # INFERRED
                 "inferred":["inferred", "inferred by author","inferred by curator"],

                 # UNESPECIFIC
                 "invitro":["invitro","in vitro","vitrobind", "in vitro binding", "vt"],  #HE ANADIDO LAS DE VITROBIND
                 "invivo":["invivo","in vivo"],
                 "experimental":["experimental","experimental knowledge based", "lab", "experimental interaction detection", "experimental interac"],
                 
                 
                 # 3D STRUCTURE
                 "3dstruct": ["3dstruct", "three dimensional structure", "3d structure", "xcryst", "x-ray crystallograph","x-ray crystallography", "x-ray: x-ray crystallography", "x-ray crystallography", "xscat", "x-ray scattering", "pdb_int", "coming from pdb", "x-ray diffraction", "co-crystal structure"],

                 # OTHER
                 "adhesion":["adhesion", "interaction adhesion", "interaction adhesion assay"],
                 "alanine":["alanine", "alanine scanning"],  
                 "biacore":["biacore", "biacore sensor chip"],       
                 "bluenat":["blunat", "blue native page","bn-page"],
                 "bifc":["bifc"],  
                 #"bret":["bret"], # Set as coloc
                 "calcium":["calcium", "calcium mobilization", "calcium mobilization assay"], 
                 "chemotaxis":["chemotaxis"],
                 "cofractionation":["cofractionation", "Co-fractionation"],
                 "crosslink":["crosslink", "cross-linking", "cross-linking studies", "cross linking", "protein crosslink"],        
                 "density":["density", "density gradient sed", "gradient sedimentation", "density gradient sedimentation","density sedimentatio"],
                 "fret":["fret", "fret analysis"],
                 "lumires":["lumires", "bioluminescence resonance energy transfer"],         
                 "microtiter":["microtiter", "microtiter plate bin", "microtiter plate binding assay"], 
                 "monoclon":["monoclon", "monoclonal antibody", "monoclonal antibody blockade"],  
                 "nuctrans":["nuctrans", "nuclear translocatio", "nuclear translocation", "nuclear translocation assay"], 
                 "protpeptide":["protpeptide","protein-peptide"],
                 "protrna":["protrna","protein-rna"],
                 "radiography":["radiography", "autoradiography"],
                 "reconstituted":["reconstitued","reconstituted complex"],
                 "spot":["spot", "peptide spot assay"]
                 }

# --------
# Definition of expansion types
# --------
# Attention! Use lowercase
# Attention! Use short names
expansion_types = {"cog":["cog", "expansionsamecog" ],
                   "ec":["ec", "expansionsameec"],
                   "interpro":["interpro", "expansionsameinterpro"],
                   "scop":["scop", "expansionsamescop"]
                   }


# Dictionary to group different methods in a hierarchical way. Not finished!

## methods_tree = { "proteincomplassay": ["cytcomplassay","membrcomplassay","transcrcomplassay","compl"], #protein complementation assay
##                  "cytcomplassay": ["dhfr","ubiquitin","betagalactcompl","adenylate","gfpcompl","betalactcompl"], #cytoplasm complementation assay
##                  "membrcomplassay": ["mappit","toxcat"], #membrane complementation assay
##                  "transcrcomplassay": ["gallex","y2hassay","3hybrid","transcrcompl","lambda"], #transcriptional complementation assay

##                  "y2hassay":["y2h","y2hpool","y2array"], # yeast two hybrid assay
                 

##                  "phagedisplay": ["t7phage","lambdaphage","phage"],

##                  "enzimatic":["polimassay","phosphassay","kinassay","methiltransassay","deacetilassay","enzimaticassay","gtpaseassay"],

##                  "footprinting": ["footprint"],

##                  "copurification":[],

##                  "array":["arraytec","antibodyarray","microarray"],

##                  "unclass":["unclassified"],

##                  "colocalization":["coloc","elecmicr","flumicro","electom","immstain","immloc"]

                 

                 
##                  }


# --------
# Definition of expansion types
# --------
# Attention! Use lowercase
# Attention! Use short names
expansion_types = {"cog":["cog", "expansionsamecog" ],
                   "ec":["ec", "expansionsameec"],
                   "interpro":["interpro", "expansionsameinterpro"],
                   "scop":["scop", "expansionsamescop"]
                   }


# ==========================================================
# COLOR CODES FOR OUTPUT NETWORK
# ==========================================================
#
# The following dictionaries set the color code that will be used
# for output
#

# For more information on these databases, please refer to piana/README.populate_piana_db

# colors for interactions depending on the database they come from

# TO DO!!! This has to be automatized so that new names are easy to add
interaction_source_databases_colors = { "dip":"red",
                                        "bind":"grey",
                                        "string":"magenta",
                                        "ori":"green",   
                                        "mint":"lightblue",  
                                        "hprd":"blue",    
                                        "mips":"darkgreen",            
                                        "biogrid":"pink",      
                                        "intersection":"cyan",     
                                        "user":"yellow",
                                        "intact":"brown",
                                        "":"black"
                                        }

# line styles depending on the type of interaction they are
interaction_line_styles = {"extended":"dashed",
                           "propagated":"dotted",
                           "normal":"solid"
                           }

# colors for node background fill depending on the type of node they are
node_fill_colors = {"root":"yellow",
                    "keyword":"red",
                    "root_keyword":"orange",
                    "normal":"lightblue"
                    }

over_and_infra_expressed_protein = "over_and_under_expressed"
over_expressed_protein = "over_expressed"
infra_expressed_protein = "under_expressed"

# colors for node borders depending on the origin of the node
node_border_colors  = {"expanded":"blue",
                       PianaGlobals.over_and_infra_expressed_protein:"orange",
                       PianaGlobals.over_expressed_protein:"red",
                       PianaGlobals.infra_expressed_protein:"green",
                       "normal":"black"
                       }

# colors for node font colors depending on the **** of the node
#node_font_colors  = {"....":"red",
#                      "normal":"black"
#                      }

# ==========================================================
# PARAMETERS FOR OUTPUT .DOT NETWORK
# ==========================================================
#
# The following parameters set the parameters that will be used
# for the output .dot network. You can modify them here as you wish
#
# For better understanding the different parameters you can take a look
# to the neato documentation: http://www.graphviz.org

dot_orientation = "portrait"
dot_pack= "true"
dot_overlap= "scale"

dot_node_shape= "box"
dot_node_font_size = "10"
dot_node_width= "0.15"
dot_node_height= "0.15"
dot_node_style = "filled"
dot_standard_node_fill_color= node_fill_colors["normal"]  # for non standard nodes, the colors can be set above

dot_edge_lenght = "1"

# ====================================
# PARAMETERS FOR OUTPUTING INFORMATION
# ====================================
#
# Set here which separators will be used depending on the format mode chosen by user

tab_separators = { "html": " ",
                   "txt": "\t"}

line_separators = { "html": "<br>",
                    "txt": "\n"}

# Set here which values will be used depending on the format mode chosen by user


positive_location_value = { "html": "yes",
                            "txt": "same",
                           "dot": "",
                           "sif": ""}

negative_location_value = { "html": "no",
                            "txt": "different",
                           "dot": "",
                           "sif": ""}

positive_species_value = { "html": "yes",
                           "txt": "same",
                           "dot": "",
                           "sif": ""}

negative_species_value = { "html": "no",
                           "txt": "different",
                           "dot": "",
                           "sif": ""}

positive_root_value = { "html": "yes",
                        "txt": "is-root",
                        "dot": "",
                        "sif": ""}

negative_root_value = { "html": "no",
                        "txt": "not-root",
                        "dot": "",
                        "sif": ""}
